// java wrapper for vtkPCorrelativeStatistics object
//

package vtk;
import vtk.*;

public class vtkPCorrelativeStatistics extends vtkCorrelativeStatistics
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetController_2(vtkMultiProcessController id0);
  public void SetController(vtkMultiProcessController id0)
    { SetController_2(id0); }

  private native long GetController_3();
  public vtkMultiProcessController GetController() {
    long temp = GetController_3();

    if (temp == 0) return null;
    return (vtkMultiProcessController)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void Learn_4(vtkTable id0,vtkTable id1,vtkMultiBlockDataSet id2);
  public void Learn(vtkTable id0,vtkTable id1,vtkMultiBlockDataSet id2)
    { Learn_4(id0,id1,id2); }

  private native void Test_5(vtkTable id0,vtkMultiBlockDataSet id1,vtkTable id2);
  public void Test(vtkTable id0,vtkMultiBlockDataSet id1,vtkTable id2)
    { Test_5(id0,id1,id2); }

  public vtkPCorrelativeStatistics() { super(); }

  public vtkPCorrelativeStatistics(long id) { super(id); }
  public native long   VTKInit();

}
